export declare const schema = "https://raw.githubusercontent.com/martinring/tmlanguage/master/tmlanguage.json";
/**
 * Special scope that indicates a larger construct that doesn't get a single color.
 * Expanded to meta.<key>.<grammar name> during emit.
 */
export declare const meta: unique symbol;
export interface RuleKey {
    /** Rule's unique key through which identifies the rule in the repository. */
    key: string;
}
export interface RuleScope<Scope extends string = string> {
    /**
     * The TextMate scope that gets assigned to a match and colored by a theme.
     * See https://macromates.com/manual/en/language_grammars#naming_conventions
     */
    scope: Scope | typeof meta;
}
export interface RulePatterns<Scope extends string = string> {
    patterns: Rule<Scope>[];
}
export type Captures<Scope extends string = string> = Record<string, RuleScope<Scope> | RulePatterns<Scope>>;
export type Rule<Scope extends string = string> = MatchRule<Scope> | BeginEndRule<Scope> | IncludeRule<Scope>;
export interface MatchRule<Scope extends string = string> extends RuleScope<Scope>, RuleKey {
    match: string;
    captures?: Captures<Scope>;
}
export interface BeginEndRule<Scope extends string = string> extends RuleKey, RuleScope<Scope>, Partial<RulePatterns<Scope>> {
    begin: string;
    end: string;
    beginCaptures?: Captures<Scope>;
    endCaptures?: Captures<Scope>;
}
export interface IncludeRule<Scope extends string = string> extends RuleKey, RulePatterns<Scope> {
}
export interface Grammar<Scope extends string = string> extends RulePatterns<Scope> {
    $schema: typeof schema;
    name: string;
    scopeName: string;
    fileTypes: string[];
}
export interface EmitOptions {
    errorSourceFilePath?: string;
}
/**
 * Emit the given grammar to JSON.
 */
export declare function emitJSON(grammar: Grammar, options?: EmitOptions): Promise<string>;
/**
 * Emit the given grammar to PList XML
 */
export declare function emitPList(grammar: Grammar, options?: EmitOptions): Promise<string>;
//# sourceMappingURL=tmlanguage-generator.d.ts.map